.. currentmodule:: eddy_footprint

.. _api:

#############
API reference
#############

This page provides an auto-generated summary of eddy-footprint's API.

Top-level functions
===================

.. autosummary::
   :toctree: generated/

   calc_footprint
